@@ -63,6 +63,21 @@
 #define MODE_DUAL_STRING	"DUAL"
 
 
+enum {
+	STRUT_LEFT = 0,
+	STRUT_RIGHT = 1,
+	STRUT_TOP = 2,
+	STRUT_BOTTOM = 3,
+	STRUT_LEFT_START = 4,
+	STRUT_LEFT_END = 5,
+	STRUT_RIGHT_START = 6,
+	STRUT_RIGHT_END = 7,
+	STRUT_TOP_START = 8,
+	STRUT_TOP_END = 9,
+	STRUT_BOTTOM_START = 10,
+	STRUT_BOTTOM_END = 11
+};
+
 typedef enum
 {
     BRLMON_PANEL_TOP,
@@ -74,6 +89,8 @@ typedef enum
 static gint our_resize_width  = DEFAULT_PANEL_WIDTH;
 static gint our_resize_height = DEFAULT_PANEL_HEIGHT;
 
+static gint _screen_width;
+
 static void	brlmon_changes_cb	(GConfClient	*client,
 					guint		cnxn_id,
 					GConfEntry	*entry,
@@ -84,6 +101,7 @@ static void     brlmon_main_resize_window (GtkWidget* pWindow,
 					    gint height,
 					    BrlmonWindowPosition window_position);
 
+void brlmon_update_struts (gint height, GtkWidget *widget);
 
 /**
  *
@@ -545,6 +563,8 @@ brlmon_get_string_with_default (const gchar *key, gchar *def)
  *
  * return: modetype.
 **/
+
+/*FIXME when brlmon will be rewritten.*/
 ModeType
 brlmon_get_mode_type_from_string (const gchar *mode)
 {
@@ -555,9 +575,9 @@ brlmon_get_mode_type_from_string (const gchar *mode)
     
     if (!strcmp (tmp, MODE_NORMAL_STRING))  modetype = MODE_NORMAL;
 	else
-    if (!strcmp (tmp, MODE_BRAILLE_STRING)) modetype = MODE_BRAILLE;
+    if (!strcmp (tmp, MODE_BRAILLE_STRING)) modetype = MODE_NORMAL;
 	else
-    if (!strcmp (tmp, MODE_DUAL_STRING))    modetype = MODE_DUAL;
+    if (!strcmp (tmp, MODE_DUAL_STRING))    modetype = MODE_NORMAL;
 	else
     {
 	sru_warning (_("Invalid modetype: %s."), mode);		    
@@ -568,6 +588,7 @@ brlmon_get_mode_type_from_string (const gchar *mode)
     
     return modetype;
 }
+/*FIXME END*/
 
 /**
  * brlmon_get_font_size
@@ -1415,6 +1436,8 @@ brlmon_main_resize_window  (GtkWidget* pwindow,
 	/* store these values */
 	our_resize_width = width;
 	our_resize_height = height;
+
+	brlmon_update_struts (our_resize_height, pwindow);
 }
 
 /**
@@ -1490,6 +1513,48 @@ brlmon_on_window_destroy   (GtkObject       *object,
 {
 }
 
+/*
+ * Update brlmon's strut allocation
+ */
+void
+brlmon_update_struts (gint height, GtkWidget *widget)
+{
+	Atom atom_strut = gdk_x11_get_xatom_by_name ("_NET_WM_STRUT");
+	Atom atom_strut_partial = gdk_x11_get_xatom_by_name ("_NET_WM_STRUT_PARTIAL");
+	guint32 struts[12] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+	BrlmonWindowPosition position = brlmon_return_panel_position ();
+
+	if (position == BRLMON_PANEL_TOP) /*( brlmon_is_top)*/
+	{
+		struts[STRUT_TOP] = height;
+		struts[STRUT_TOP_START] = 0;
+		struts[STRUT_TOP_END] = _screen_width - 1;
+	}
+	else if (position == BRLMON_PANEL_BOTTOM)
+	{
+		struts[STRUT_BOTTOM] = height;
+		struts[STRUT_BOTTOM_START] = 0;
+		struts[STRUT_BOTTOM_END] = _screen_width - 1;
+	}
+
+	gdk_error_trap_push ();
+	/* this means that we are responsible for placing ourselves appropriately on screen */
+	if (widget && widget->window)
+	{
+		XChangeProperty (GDK_WINDOW_XDISPLAY (widget->window), 
+				 GDK_WINDOW_XWINDOW (widget->window), 
+				 atom_strut,
+				 XA_CARDINAL, 32, PropModeReplace,
+				 (guchar *) &struts, 4);
+		XChangeProperty (GDK_WINDOW_XDISPLAY (widget->window), 
+				 GDK_WINDOW_XWINDOW (widget->window), 
+				 atom_strut_partial,
+				 XA_CARDINAL, 32, PropModeReplace,
+				 (guchar *) &struts, 12);
+	}
+	gdk_error_trap_pop ();
+}
+
 /**
  * brlmon_on_window_realize
  *
@@ -1524,6 +1589,7 @@ brlmon_on_window_realize (GtkWidget       *widget,
     
     XSetWMProtocols (GDK_WINDOW_XDISPLAY (widget->window),
 		   GDK_WINDOW_XWINDOW (widget->window), wm_window_protocols, 3);
+
     gdk_error_trap_pop ();
 
     if (is_dock) 
@@ -1540,6 +1606,8 @@ brlmon_on_window_realize (GtkWidget       *widget,
 	  }
     }
     
+    brlmon_update_struts (our_resize_height, widget);
+
     /* stick window for all desktop screen */
     gtk_window_stick (GTK_WINDOW (widget));
 
@@ -1561,6 +1629,8 @@ GtkWidget*
 brlmon_main_create_window (gboolean is_dock)
 {
 	GtkWidget *window1;
+	_screen_width = gdk_screen_get_width (gdk_screen_get_default ()); 
+        /* FIXME: is brlmon always on the default screen? */
 						     
 	window1 = g_object_connect (gtk_widget_new (gtk_window_get_type (),
 				"user_data", NULL,
