@@ -1393,6 +1393,36 @@ spui_voice_absolute_handlers_set  (GladeXML *xml)
     spui_speech_voice_absolute.ck_abs_rate 	   	= glade_xml_get_widget (xml, "ck_abs_rate_active");
     spui_speech_voice_absolute.ck_abs_volume 	   	= glade_xml_get_widget (xml, "ck_abs_volume_active");    
 
+    gtk_spin_button_set_range (GTK_SPIN_BUTTON (spui_speech_voice_absolute.sp_abs_pitch),
+				    MIN_SPEECH_PITCH, MAX_SPEECH_PITCH);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (spui_speech_voice_absolute.sp_abs_pitch),
+				    DEFAULT_SPEECH_PITCH);
+
+    gtk_spin_button_set_range (GTK_SPIN_BUTTON (spui_speech_voice_absolute.sp_abs_rate),
+				    MIN_SPEECH_RATE, MAX_SPEECH_RATE);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (spui_speech_voice_absolute.sp_abs_rate),
+				    DEFAULT_SPEECH_RATE);
+
+    gtk_spin_button_set_range (GTK_SPIN_BUTTON (spui_speech_voice_absolute.sp_abs_volume),
+				    MIN_SPEECH_VOLUME, MAX_SPEECH_VOLUME);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (spui_speech_voice_absolute.sp_abs_volume),
+				    DEFAULT_SPEECH_VOLUME);
+
+    gtk_range_set_range (GTK_RANGE (spui_speech_voice_absolute.hs_abs_pitch),
+				    MIN_SPEECH_PITCH, MAX_SPEECH_PITCH);
+    gtk_range_set_value (GTK_RANGE (spui_speech_voice_absolute.hs_abs_pitch),
+				    DEFAULT_SPEECH_PITCH);
+
+    gtk_range_set_range (GTK_RANGE (spui_speech_voice_absolute.hs_abs_rate),
+				    MIN_SPEECH_RATE, MAX_SPEECH_RATE);
+    gtk_range_set_value (GTK_RANGE (spui_speech_voice_absolute.hs_abs_rate),
+				    DEFAULT_SPEECH_RATE);
+
+    gtk_range_set_range (GTK_RANGE (spui_speech_voice_absolute.hs_abs_volume),
+				    MIN_SPEECH_VOLUME, MAX_SPEECH_VOLUME);
+    gtk_range_set_value (GTK_RANGE (spui_speech_voice_absolute.hs_abs_volume),
+				    DEFAULT_SPEECH_VOLUME);
+
     g_object_set_data (G_OBJECT (spui_speech_voice_absolute.ck_abs_volume), 
 			"abs_volume", glade_xml_get_widget (xml, "lb_abs_volume"));
     g_object_set_data (G_OBJECT (spui_speech_voice_absolute.ck_abs_volume), 
