@@ -60,8 +60,8 @@ typedef struct
     gint 		 zp_bottom;
 
     	
-    gint		 zoom_factor_x;
-    gint		 zoom_factor_y; 
+    gdouble		 zoom_factor_x;
+    gdouble     	 zoom_factor_y; 
     gboolean 	 	 zoom_factor_lock;
     /*	float 		 contrast*/	
     gboolean	 	 invert;	
@@ -75,7 +75,6 @@ typedef struct
     gboolean	 	 visible;
 } SRCMagnifier;
 
-
 SRCMagnifier	      	*src_magnifier = NULL;
 gboolean   		magnifier_initialized = 0;
 gboolean	        panning = FALSE;
@@ -311,9 +310,9 @@ src_magnifier_panning (SRObject *obj)
 	
     if (panning && old_panning)
     {
-	panning_handle = gtk_timeout_add (100,
-					src_magnifier_automatic_panning,
-					old_panning);
+	if (obj) panning_handle = gtk_timeout_add (100,
+						   src_magnifier_automatic_panning,
+						   old_panning);
     }
     return TRUE;
 }
@@ -455,8 +454,8 @@ src_magnifier_create_mml(const SRCMagnifier *magnifier)
 			    " ZPTop=\"%d\""
 			    " ZPWidth=\"%d\""
 			    " ZPHeight=\"%d\""
-			    " ZoomFactorX=\"%d\""
-			    " ZoomFactorY=\"%d\""
+			    " ZoomFactorX=\"%f\""
+			    " ZoomFactorY=\"%f\""
 			    " invert=\"%d\""
 			    " smoothing=\"%s\""
 			    " tracking=\"%s\""
@@ -552,6 +551,7 @@ src_magnifier_load_values (SRCMagnifier *magnifier)
 {
     gboolean   default_bool_val;
     gint       default_int_val;
+    gdouble    default_float_val;
 /*    gchar     *default_string_val = NULL;*/
     gint 	size_x,
 		size_y;
@@ -732,17 +732,17 @@ src_magnifier_load_values (SRCMagnifier *magnifier)
 				      (gpointer)DEFAULT_MAGNIFIER_TARGET, 
 				      MAGNIFIER_CONFIG_PATH);
 
-    default_int_val = DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
+    default_float_val = DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
     srconf_get_data_with_default (MAGNIFIER_ZOOM_FACTOR_X, 
-				       CFGT_INT, 
+				       CFGT_FLOAT, 
 				       (gpointer)&magnifier->zoom_factor_x, 
-				       (gpointer)&default_int_val, 
+				       (gpointer)&default_float_val, 
 				       MAGNIFIER_CONFIG_PATH);
 
     srconf_get_data_with_default (MAGNIFIER_ZOOM_FACTOR_Y, 
-				       CFGT_INT, 
+				       CFGT_FLOAT, 
 				       (gpointer)&magnifier->zoom_factor_y, 
-				       (gpointer)&default_int_val, 
+				       (gpointer)&default_float_val, 
 				       MAGNIFIER_CONFIG_PATH);
 /*    magnifier->mag_zoom_factor_lock = DEFAULT_MAGNIFIER_ZOOM_FACTOR_LOCK;*/
 
@@ -832,7 +832,7 @@ src_magnifier_config_set_defaults (SRCMagnifier *magnifier)
 		     __FILE__, __LINE__);
     
     if (!srconf_set_data (MAGNIFIER_ZOOM_FACTOR_Y,
-			  CFGT_INT, 
+			  CFGT_FLOAT, 
 			  (gpointer)&magnifier->zoom_factor_y,
 			  MAGNIFIER_CONFIG_PATH)
 	)
@@ -840,7 +840,7 @@ src_magnifier_config_set_defaults (SRCMagnifier *magnifier)
 		     __FILE__, __LINE__);
     
     if (!srconf_set_data (MAGNIFIER_ZOOM_FACTOR_X,
-			  CFGT_INT, 
+			  CFGT_FLOAT, 
 			  (gpointer)&magnifier->zoom_factor_x,
 			  MAGNIFIER_CONFIG_PATH)
 	)
@@ -1581,7 +1581,7 @@ src_magnifier_set_source (gchar *source)
 }
 
 gboolean
-src_magnifier_set_zoom_factor_x (gint zoom_factor_x)
+src_magnifier_set_zoom_factor_x (gdouble zoom_factor_x)
 {
     SRCMagnifier *magnifier;
     gchar *val = NULL;
@@ -1593,7 +1593,7 @@ src_magnifier_set_zoom_factor_x (gint zoom_factor_x)
     if (zoom_factor_x != magnifier->zoom_factor_x)
     {
 	magnifier->zoom_factor_x = zoom_factor_x;
-	val = g_strdup_printf ("<MAGOUT><ZOOMER ID=\"generic_zoomer\" ZoomFactorX=\"%d\"></ZOOMER></MAGOUT>",
+	val = g_strdup_printf ("<MAGOUT><ZOOMER ID=\"generic_zoomer\" ZoomFactorX=\"%f\"></ZOOMER></MAGOUT>",
 			       zoom_factor_x);
 		
 	g_assert (val);	       
@@ -1657,7 +1657,7 @@ src_magnifier_decrease_x_scale ()
 }
 
 gboolean
-src_magnifier_set_zoom_factor_y (gint zoom_factor_y)
+src_magnifier_set_zoom_factor_y (gdouble zoom_factor_y)
 {
     SRCMagnifier *magnifier;
     gchar *val = NULL;
@@ -1670,7 +1670,7 @@ src_magnifier_set_zoom_factor_y (gint zoom_factor_y)
     {
 	magnifier->zoom_factor_y = zoom_factor_y;
 	
-	val = g_strdup_printf ("<MAGOUT><ZOOMER ID=\"generic_zoomer\" ZoomFactorY=\"%d\"></ZOOMER></MAGOUT>",
+	val = g_strdup_printf ("<MAGOUT><ZOOMER ID=\"generic_zoomer\" ZoomFactorY=\"%f\"></ZOOMER></MAGOUT>",
 			       zoom_factor_y);
 		
 	g_assert (val);	       
